# bib 
bib is a special library, which aims to organize and standardize bib files, so as to facilitate relevant personnel to read and find the information in the files.

The following modules are available. These contain some functions, that can be used by your own codebase.

  - bibcopy.PythonList - 如何如何。
  - bibcopy.qiyuhanshu - 如何如
  
We build and maintain bib, so if we encounter bugs in the process of using it, we can provide relevant information to 937207118@qq.com.

See the [storehouse](https://gitee.com/chen-kun19/summer-program) for guidelines and code references for using bib.

## [Compatibility]

bib 1.0.6 supports Python3.

## [Installing Bib]
We provide complete source code, so you can download all the relevant information of bib.

Instructions are as follows：

    pip install Test

Then in py file, through instruction：

    from fb inmport bibcopy
In this way, you can use the functions described above.

## [Contributing]
Are you a developer? Do you want to integrate bib into your project and contribute back? Great! Just do it and if you have any questions, please contact me through [it](937207118@qq.com).



  

